@@ -1,4 +1,13 @@
-#include <stdlib.h>
+// SPDX-License-Identifier: GPL-2.0-or-later
+/** @file
+ * TODO: insert short description here
+ *//*
+ * Authors: see git history
+ *
+ * Copyright (C) 2018 Authors
+ * Released under GNU GPL v2+, read the file 'COPYING' for more information.
+ */
+#include <cstdlib>
 
 #include "imagemap-gdk.h"
 
@@ -10,7 +19,7 @@
 GrayMap *gdkPixbufToGrayMap(GdkPixbuf *buf)
 {
     if (!buf)
-        return NULL;
+        return nullptr;
 
     int width       = gdk_pixbuf_get_width(buf);
     int height      = gdk_pixbuf_get_height(buf);
@@ -20,7 +29,7 @@ GrayMap *gdkPixbufToGrayMap(GdkPixbuf *buf)
 
     GrayMap *grayMap = GrayMapCreate(width, height);
     if (!grayMap)
-        return NULL;
+        return nullptr;
 
     //### Fill in the odd cells with RGB values
     int x,y;
@@ -46,19 +55,22 @@ GrayMap *gdkPixbufToGrayMap(GdkPixbuf *buf)
 GdkPixbuf *grayMapToGdkPixbuf(GrayMap *grayMap)
 {
     if (!grayMap)
-        return NULL;
+        return nullptr;
 
     guchar *pixdata = (guchar *)
           malloc(sizeof(guchar) * grayMap->width * grayMap->height * 3);
     if (!pixdata)
-        return NULL;
+        {
+        g_warning("grayMapToGdkPixbuf: can not allocate memory for conversion.");
+        return nullptr;
+        }
 
     int n_channels = 3;
     int rowstride  = grayMap->width * 3;
 
     GdkPixbuf *buf = gdk_pixbuf_new_from_data(pixdata, GDK_COLORSPACE_RGB,
                         0, 8, grayMap->width, grayMap->height,
-                        rowstride, (GdkPixbufDestroyNotify)g_free, NULL);
+                        rowstride, (GdkPixbufDestroyNotify)g_free, nullptr);
 
     //### Fill in the odd cells with RGB values
     int x,y;
@@ -79,88 +91,6 @@ GdkPixbuf *grayMapToGdkPixbuf(GrayMap *grayMap)
 }
 
 
-
-/*#########################################################################
-## P A C K E D    P I X E L    M A P
-#########################################################################*/
-
-PackedPixelMap *gdkPixbufToPackedPixelMap(GdkPixbuf *buf)
-{
-    if (!buf)
-        return NULL;
-
-    int width       = gdk_pixbuf_get_width(buf);
-    int height      = gdk_pixbuf_get_height(buf);
-    guchar *pixdata = gdk_pixbuf_get_pixels(buf);
-    int rowstride   = gdk_pixbuf_get_rowstride(buf);
-    int n_channels  = gdk_pixbuf_get_n_channels(buf);
-
-    PackedPixelMap *ppMap = PackedPixelMapCreate(width, height);
-    if (!ppMap)
-        return NULL;
-
-    //### Fill in the cells with RGB values
-    int x,y;
-    int row  = 0;
-    for (y=0 ; y<height ; y++)
-        {
-        guchar *p = pixdata + row;
-        for (x=0 ; x<width ; x++)
-            {
-            int alpha = (int)p[3];
-            int white = 255 - alpha;
-            int r     = (int)p[0];  r = r * alpha / 256 + white;
-            int g     = (int)p[1];  g = g * alpha / 256 + white;
-            int b     = (int)p[2];  b = b * alpha / 256 + white;
-
-            ppMap->setPixel(ppMap, x, y, r, g, b);
-            p += n_channels;
-            }
-        row += rowstride;
-        }
-
-    return ppMap;
-}
-
-/*GdkPixbuf *packedPixelMapToGdkPixbuf(PackedPixelMap *ppMap)
-{
-    if (!ppMap)
-        return NULL;
-
-    guchar *pixdata = (guchar *)
-          malloc(sizeof(guchar) * ppMap->width * ppMap->height * 3);
-    if (!pixdata)
-        return NULL;
-
-    int n_channels = 3;
-    int rowstride  = ppMap->width * 3;
-
-    GdkPixbuf *buf = gdk_pixbuf_new_from_data(pixdata, GDK_COLORSPACE_RGB,
-                        0, 8, ppMap->width, ppMap->height,
-                        rowstride, NULL, NULL); //first NULL: replace by (GdkPixbufDestroyNotify)g_free ??
-
-    //### Fill in the cells with RGB values
-    int x,y;
-    int row  = 0;
-    for (y=0 ; y<ppMap->height ; y++)
-        {
-        guchar *p = pixdata + row;
-        for (x=0 ; x<ppMap->width ; x++)
-            {
-            unsigned long rgb = ppMap->getPixel(ppMap, x, y);
-            p[0] = (rgb >> 16) & 0xff;
-            p[1] = (rgb >>  8) & 0xff;
-            p[2] = (rgb      ) & 0xff;
-            p += n_channels;
-            }
-        row += rowstride;
-        }
-
-    return buf;
-}
-*/
-
-
 /*#########################################################################
 ## R G B   M A P
 #########################################################################*/
@@ -168,7 +98,7 @@ PackedPixelMap *gdkPixbufToPackedPixelMap(GdkPixbuf *buf)
 RgbMap *gdkPixbufToRgbMap(GdkPixbuf *buf)
 {
     if (!buf)
-        return NULL;
+        return nullptr;
 
     int width       = gdk_pixbuf_get_width(buf);
     int height      = gdk_pixbuf_get_height(buf);
@@ -178,7 +108,7 @@ RgbMap *gdkPixbufToRgbMap(GdkPixbuf *buf)
 
     RgbMap *rgbMap = RgbMapCreate(width, height);
     if (!rgbMap)
-        return NULL;
+        return nullptr;
 
     //### Fill in the cells with RGB values
     int x,y;
@@ -203,44 +133,7 @@ RgbMap *gdkPixbufToRgbMap(GdkPixbuf *buf)
     return rgbMap;
 }
 
-/*
-GdkPixbuf *rgbMapToGdkPixbuf(RgbMap *rgbMap)
-{
-    if (!rgbMap)
-        return NULL;
 
-    guchar *pixdata = (guchar *)
-          malloc(sizeof(guchar) * rgbMap->width * rgbMap->height * 3);
-    if (!pixdata)
-        return NULL;
-
-    int n_channels = 3;
-    int rowstride  = rgbMap->width * 3;
-
-    GdkPixbuf *buf = gdk_pixbuf_new_from_data(pixdata, GDK_COLORSPACE_RGB,
-                        0, 8, rgbMap->width, rgbMap->height,
-                        rowstride, NULL, NULL); //first NULL: replace by (GdkPixbufDestroyNotify)g_free ??
-
-    //### Fill in the cells with RGB values
-    int x,y;
-    int row  = 0;
-    for (y=0 ; y<rgbMap->height ; y++)
-        {
-        guchar *p = pixdata + row;
-        for (x=0 ; x<rgbMap->width ; x++)
-            {
-            RGB rgb = rgbMap->getPixel(rgbMap, x, y);
-            p[0] = rgb.r & 0xff;
-            p[1] = rgb.g & 0xff;
-            p[2] = rgb.b & 0xff;
-            p += n_channels;
-            }
-        row += rowstride;
-        }
-
-    return buf;
-}
-*/
 
 /*#########################################################################
 ## I N D E X E D   M A P
@@ -250,19 +143,22 @@ GdkPixbuf *rgbMapToGdkPixbuf(RgbMap *rgbMap)
 GdkPixbuf *indexedMapToGdkPixbuf(IndexedMap *iMap)
 {
     if (!iMap)
-        return NULL;
+        return nullptr;
 
     guchar *pixdata = (guchar *)
           malloc(sizeof(guchar) * iMap->width * iMap->height * 3);
     if (!pixdata)
-        return NULL;
+        {
+        g_warning("indexedMapToGdkPixbuf: can not allocate memory for conversion.");
+        return nullptr;
+        }
 
     int n_channels = 3;
     int rowstride  = iMap->width * 3;
 
     GdkPixbuf *buf = gdk_pixbuf_new_from_data(pixdata, GDK_COLORSPACE_RGB,
                         0, 8, iMap->width, iMap->height,
-                        rowstride, (GdkPixbufDestroyNotify)g_free, NULL);
+                        rowstride, (GdkPixbufDestroyNotify)g_free, nullptr);
 
     //### Fill in the cells with RGB values
     int x,y;
